[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
20/23: gnu: python-path: Use pyproject-build-system.
From: |
guix-commits |
Subject: |
20/23: gnu: python-path: Use pyproject-build-system. |
Date: |
Thu, 27 Oct 2022 13:47:13 -0400 (EDT) |
mbakke pushed a commit to branch master
in repository guix.
commit d2e88c383b84ef84efcab3a32af013c80a117ccd
Author: Marius Bakke <marius@gnu.org>
AuthorDate: Fri Oct 21 00:32:29 2022 +0200
gnu: python-path: Use pyproject-build-system.
* gnu/packages/python-xyz.scm (python-path-bootstrap)[build-system]: Switch
to
PYPROJECT-BUILD-SYSTEM.
[arguments]: Remove #:phases.
[native-inputs]: Remove PYTHON-PYPA-BUILD.
(python-path): Remove #:phases. Add #:test-flags.
---
gnu/packages/python-xyz.scm | 42 ++++++++++++------------------------------
1 file changed, 12 insertions(+), 30 deletions(-)
diff --git a/gnu/packages/python-xyz.scm b/gnu/packages/python-xyz.scm
index 922eacdc51..7fa8974c74 100644
--- a/gnu/packages/python-xyz.scm
+++ b/gnu/packages/python-xyz.scm
@@ -12733,25 +12733,10 @@ domains support.")
(uri (pypi-uri "path" version))
(sha256
(base32 "0lig13gxnfv98v790db1smvsbd3mnj7y8rwyiwhfi6xiqibygwms"))))
- (build-system python-build-system)
+ (build-system pyproject-build-system)
(arguments
- (list
- #:tests? #f
- #:phases
- #~(modify-phases %standard-phases
- ;; XXX: PEP 517 manual build/install procedures copied from
- ;; python-isort.
- (replace 'build
- (lambda _
- ;; ZIP does not support timestamps before 1980.
- (setenv "SOURCE_DATE_EPOCH" "315532800")
- (invoke "python" "-m" "build" "--wheel" "--no-isolation" ".")))
- (replace 'install
- (lambda* (#:key outputs #:allow-other-keys)
- (let ((whl (car (find-files "dist" "\\.whl$"))))
- (invoke "pip" "--no-cache-dir" "--no-input"
- "install" "--no-deps" "--prefix" #$output whl)))))))
- (native-inputs (list python-pypa-build python-setuptools-scm))
+ (list #:tests? #f))
+ (native-inputs (list python-setuptools-scm))
(home-page "https://github.com/jaraco/path")
(synopsis "Object-oriented file system path manipulation library")
(description "@code{path} (formerly @code{path.py}) implements path
@@ -12767,18 +12752,15 @@ invoked on those path objects directly.")
(package-arguments python-path-bootstrap)
((#:tests? _ #f)
(not (%current-target-system)))
- ((#:phases phases #~%standard-phases)
- #~(modify-phases #$phases
- (replace 'check
- (lambda* (#:key tests? #:allow-other-keys)
- (when tests?
- ;; Do not test the myproject.toml build as it tries to pull
- ;; dependencies from the Internet.
- (invoke "pytest" "-vv" "-k"
- (string-append
- "not project "
- ;; This tests assumes a root user exists.
- "and not test_get_owner")))))))))
+ ((#:test-flags flags #~'())
+ #~(append (list "-vv" "-k"
+ (string-append
+ ;; Do not test the myproject.toml build as it tries
+ ;; to pull dependencies from the Internet.
+ "not project "
+ ;; This tests assumes a root user exists.
+ "and not test_get_owner"))
+ #$flags))))
(native-inputs
(modify-inputs (package-native-inputs python-path-bootstrap)
(append python-appdirs
- branch master updated (176a501360 -> f928abac36), guix-commits, 2022/10/27
- 02/23: gnu: Zabbix: Update to 6.0.9., guix-commits, 2022/10/27
- 01/23: gnu: zabbix-agentd: Enable TLS support., guix-commits, 2022/10/27
- 03/23: gnu: python-setuptools: Move to python-build., guix-commits, 2022/10/27
- 10/23: gnu: weasyprint: Use pyproject-build-system., guix-commits, 2022/10/27
- 13/23: gnu: python-ufolib2: Use pyproject-build-system., guix-commits, 2022/10/27
- 05/23: gnu: python-pip: Move to (gnu packages python-build)., guix-commits, 2022/10/27
- 08/23: gnu: python-autopage: Use pyproject-build-system., guix-commits, 2022/10/27
- 11/23: gnu: python-glyphslib: Use pyproject-build-system., guix-commits, 2022/10/27
- 17/23: gnu: zabbix-cli: Switch to pyproject-build-system., guix-commits, 2022/10/27
- 20/23: gnu: python-path: Use pyproject-build-system.,
guix-commits <=
- 09/23: gnu: python-pydyf: Use pyproject-build-system., guix-commits, 2022/10/27
- 04/23: gnu: pypy: Move to separate module., guix-commits, 2022/10/27
- 06/23: build-system: Add pyproject-build-system., guix-commits, 2022/10/27
- 12/23: gnu: python-statmake: Use pyproject-build-system., guix-commits, 2022/10/27
- 14/23: gnu: python-mypy-protobuf: Switch to pyproject-build-system., guix-commits, 2022/10/27
- 15/23: gnu: python-tempora: Switch to pyproject-build-system., guix-commits, 2022/10/27
- 16/23: gnu: python-pygmsh: Use pyproject-build-system., guix-commits, 2022/10/27
- 19/23: gnu: python-openapi-spec-validator: Use pyproject-build-system., guix-commits, 2022/10/27
- 21/23: gnu: python-cattrs: Use pyproject-build-system., guix-commits, 2022/10/27
- 22/23: gnu: python-scikit-build: Switch to pyproject-build-system., guix-commits, 2022/10/27